@@ -23,7 +23,7 @@ pam_euclidean_method = function(dt, clusters, columnClass, metric) {
 
   start.time <- Sys.time()
 
-  on.exit(options(warn = -1))
+  on.exit(suppressWarnings())
 
   if ('data.frame' %in% class(dt))
     dt = as.matrix(dt)
@@ -111,8 +111,6 @@ pam_manhattan_method = function(dt, clusters, columnClass, metric) {
 
   start.time <- Sys.time()
 
-  on.exit(options(warn = -1))
-
   if ('data.frame' %in% class(dt))
     dt = as.matrix(dt)
 
