@@ -78,28 +78,28 @@ calculate_result <-
     if (variables) {
       sort_timeExternal <-
         sort(x = as.vector(unlist(timeExternal)),
-             decreasing = F,
-             index.return = T)$ix
+             decreasing = FALSE,
+             index.return = TRUE)$ix
     } else {
       sort_timeExternal <-
         sort(x = as.vector(unlist(timeExternal)),
              decreasing = FALSE,
-             index.return = T)$x
+             index.return = TRUE)$x
     }
     if (variables) {
       sort_entropy <-
         if (!is.null(entropy))
           sort(x = as.vector(unlist(entropy)),
-               decreasing = T,
-               index.return = T)$ix
+               decreasing = TRUE,
+               index.return = TRUE)$ix
       else
         NULL
     } else {
       sort_entropy <-
         if (!is.null(entropy))
           sort(x = as.vector(unlist(entropy)),
-               decreasing = T,
-               index.return = T)$x
+               decreasing = TRUE,
+               index.return = TRUE)$x
       else
         NULL
     }
@@ -109,8 +109,8 @@ calculate_result <-
         if (!is.null(variation_information))
           sort(
             x = as.vector(unlist(variation_information)),
-            decreasing = T,
-            index.return = T
+            decreasing = TRUE,
+            index.return = TRUE
           )$ix
       else
         NULL
@@ -119,8 +119,8 @@ calculate_result <-
         if (!is.null(variation_information))
           sort(
             x = as.vector(unlist(variation_information)),
-            decreasing = T,
-            index.return = T
+            decreasing = TRUE,
+            index.return = TRUE
           )$x
       else
         NULL
@@ -130,16 +130,16 @@ calculate_result <-
       sort_precision <-
         if (!is.null(precision))
           sort(x = as.vector(unlist(precision)),
-               decreasing = T,
-               index.return = T)$ix
+               decreasing = TRUE,
+               index.return = TRUE)$ix
       else
         NULL
     } else {
       sort_precision <-
         if (!is.null(precision))
           sort(x = as.vector(unlist(precision)),
-               decreasing = T,
-               index.return = T)$x
+               decreasing = TRUE,
+               index.return = TRUE)$x
       else
         NULL
     }
@@ -148,16 +148,16 @@ calculate_result <-
       sort_recall <-
         if (!is.null(recall))
           sort(x = as.vector(unlist(recall)),
-               decreasing = T,
-               index.return = T)$ix
+               decreasing = TRUE,
+               index.return = TRUE)$ix
       else
         NULL
     } else {
       sort_recall <-
         if (!is.null(recall))
           sort(x = as.vector(unlist(recall)),
-               decreasing = T,
-               index.return = T)$x
+               decreasing = TRUE,
+               index.return = TRUE)$x
       else
         NULL
     }
@@ -167,8 +167,8 @@ calculate_result <-
         if (!is.null(fowlkes_mallows_index))
           sort(
             unlist(x = as.vector(fowlkes_mallows_index)),
-            decreasing = T,
-            index.return = T
+            decreasing = TRUE,
+            index.return = TRUE
           )$ix
       else
         NULL
@@ -177,8 +177,8 @@ calculate_result <-
         if (!is.null(fowlkes_mallows_index))
           sort(
             x = as.vector(unlist(fowlkes_mallows_index)),
-            decreasing = T,
-            index.return = T
+            decreasing = TRUE,
+            index.return = TRUE
           )$x
       else
         NULL
@@ -188,16 +188,16 @@ calculate_result <-
       sort_f_measure <-
         if (!is.null(f_measure))
           sort(x = as.vector(unlist(f_measure)),
-               decreasing = T,
-               index.return = T)$ix
+               decreasing = TRUE,
+               index.return = TRUE)$ix
       else
         NULL
     } else {
       sort_f_measure <-
         if (!is.null(f_measure))
           sort( x = as.vector(unlist(f_measure)),
-               decreasing = T,
-               index.return = T)$x
+               decreasing = TRUE,
+               index.return = TRUE)$x
       else
         NULL
     }
@@ -205,29 +205,29 @@ calculate_result <-
     if (variables) {
       sort_timeInternal <-
        sort(  x = as.vector(unlist(timeInternal)),
-             decreasing = F,
-             index.return = T)$ix
+             decreasing = FALSE,
+             index.return = TRUE)$ix
     } else {
       sort_timeInternal <-
         sort(x = as.vector(unlist(timeInternal)),
-             decreasing = F,
-             index.return = T)$x
+             decreasing = FALSE,
+             index.return = TRUE)$x
     }
 
     if (variables) {
       sort_dunn <-
         if (!is.null(dunn))
           sort(x = as.vector(unlist(dunn)),
-               decreasing = T,
-               index.return = T)$ix
+               decreasing = TRUE,
+               index.return = TRUE)$ix
       else
         NULL
     } else {
       sort_dunn <-
         if (!is.null(dunn))
           sort(x = as.vector(unlist(dunn)),
-               decreasing = T,
-               index.return = T)$x
+               decreasing = TRUE,
+               index.return = TRUE)$x
       else
         NULL
     }
@@ -236,16 +236,16 @@ calculate_result <-
       sort_connectivity <-
         if (!is.null(connectivity))
           sort(x = as.vector(unlist(connectivity)),
-               decreasing = T,
-               index.return = T)$ix
+               decreasing = TRUE,
+               index.return = TRUE)$ix
       else
         NULL
     } else {
       sort_connectivity <-
         if (!is.null(connectivity))
           sort(x = as.vector(unlist(connectivity)),
-               decreasing = T,
-               index.return = T)$x
+               decreasing = TRUE,
+               index.return = TRUE)$x
       else
         NULL
     }
@@ -254,16 +254,16 @@ calculate_result <-
       sort_silhouette <-
         if (!is.null(silhouette))
           sort(x = as.vector(unlist(silhouette)),
-               decreasing = T,
-               index.return = T)$ix
+               decreasing = TRUE,
+               index.return = TRUE)$ix
       else
         NULL
     } else {
       sort_silhouette <-
         if (!is.null(silhouette))
           sort(x = as.vector(unlist(silhouette)),
-               decreasing = T,
-               index.return = T)$x
+               decreasing = TRUE,
+               index.return = TRUE)$x
       else
         NULL
     }
@@ -292,7 +292,7 @@ calculate_result <-
         resultadoValores$entropy = sort_entropy[ranking]
     else
       resultadoValores$entropy =format(round(as.numeric(sort_entropy[ranking]),
-                                             digits = 4),scientific = F)
+                                             digits = 4),scientific = FALSE)
     if (!is.null(sort_variation_information))
       if (variables)
       resultadoValores$variation_information =
@@ -300,47 +300,195 @@ calculate_result <-
     else
       resultadoValores$variation_information =
       format(round(as.numeric(sort_variation_information[ranking]), digits = 4),
-             scientific = F)
+             scientific = FALSE)
     if (!is.null(sort_precision))
       if (variables)  resultadoValores$precision = sort_precision[ranking]
     else resultadoValores$precision =
       format(round(as.numeric(sort_precision[ranking]), digits = 4),
-             scientific = F)
+             scientific = FALSE)
     if (!is.null(sort_recall))
       if (variables)  resultadoValores$recall = sort_recall[ranking]
     else resultadoValores$recall =
       format(round(as.numeric(sort_recall[ranking]),
-                                                digits = 4),scientific = F)
+                                                digits = 4),scientific = FALSE)
     if (!is.null(sort_f_measure))
       if (variables) resultadoValores$f_measure = sort_f_measure[ranking]
     else resultadoValores$f_measure =
-      format(round(as.numeric(sort_f_measure[ranking]), digits = 4),scientific = F)
+      format(round(as.numeric(sort_f_measure[ranking]), digits = 4),scientific = FALSE)
     if (!is.null(sort_fowlkes_mallows_index))
       if (variables)  resultadoValores$fowlkes_mallows_index =
       sort_fowlkes_mallows_index[ranking]
     else resultadoValores$fowlkes_mallows_index =
       format(round(as.numeric(sort_fowlkes_mallows_index[ranking]),
-                   digits = 4),scientific = F)
+                   digits = 4),scientific = FALSE)
     if (!is.null(sort_timeInternal))
       if (variables)  resultadoValores$timeInternal =
       match(ranking, sort_timeInternal)
     else resultadoValores$timeInternal =
       format(round(as.numeric(sort_timeInternal[ranking]),
-                   digits = 4),scientific = F)
+                   digits = 4),scientific = FALSE)
     if (!is.null(sort_connectivity))
       if (variables)  resultadoValores$connectivity = sort_connectivity[ranking]
     else resultadoValores$connectivity =
       format(round(as.numeric(sort_connectivity[ranking]), digits = 4),
-             scientific = F)
+             scientific = FALSE)
     if (!is.null(sort_dunn))
       if (variables)  resultadoValores$dunn = sort_dunn[ranking]
     else resultadoValores$dunn = format(round(as.numeric(sort_dunn[ranking]),
-                                              digits = 4),scientific = F)
+                                              digits = 4),scientific = FALSE)
     if (!is.null(sort_silhouette))
       if (variables)  resultadoValores$silhouette = sort_silhouette[ranking]
     else resultadoValores$silhouette =
       format(round(as.numeric(sort_silhouette[ranking]), digits = 4),
-             scientific = F)
+             scientific = FALSE)
+
+    return (resultadoValores)
+
+  }
+
+#'
+#' Method that returns the value or variable depending on where it is in the
+#' calculated metrics.
+#'
+#' @param algorith Algorithm name.
+#'
+#' @param distance Name of the metric used to calculate the distance between
+#' points.
+#'
+#' @param cluster Number of clusters.
+#'
+#' @param dataset Name of dataset.
+#'
+#' @param dunn Array with the calculation of the dunn for each of the variables.
+#'
+#' @param connectivity Array with the calculation of the connectivity for each
+#' of the variables.
+#'
+#' @param silhouette Array with the calculation of the silhouette for each of
+#' the variables.
+#'
+#' @param timeInternal Array with the internal validation calculation times of
+#' the clustering.
+#'
+#' @param variables True if we want to show the value of the metric calculation
+#' and false if we want to show the variable.
+#'
+#' @return Returns an array with the calculation of each metric based on the
+#' indicated position.
+#'
+#' @keywords internal
+#'
+
+calculate_result_internal <-
+  function(algorith,
+           distance,
+           cluster,
+           dataset,
+           ranking,
+           timeInternal,
+           dunn,
+           connectivity,
+           silhouette,
+           variables) {
+
+    resultadoValores = list()
+
+    if (variables) {
+      sort_timeInternal <-
+        sort(  x = as.vector(unlist(timeInternal)),
+               decreasing = FALSE,
+               index.return = TRUE)$ix
+    } else {
+      sort_timeInternal <-
+        sort(x = as.vector(unlist(timeInternal)),
+             decreasing = FALSE,
+             index.return = TRUE)$x
+    }
+
+    if (variables) {
+      sort_dunn <-
+        if (!is.null(dunn))
+          sort(x = as.vector(unlist(dunn)),
+               decreasing = TRUE,
+               index.return = TRUE)$ix
+      else
+        NULL
+    } else {
+      sort_dunn <-
+        if (!is.null(dunn))
+          sort(x = as.vector(unlist(dunn)),
+               decreasing = TRUE,
+               index.return = TRUE)$x
+      else
+        NULL
+    }
+
+    if (variables) {
+      sort_connectivity <-
+        if (!is.null(connectivity))
+          sort(x = as.vector(unlist(connectivity)),
+               decreasing = TRUE,
+               index.return = TRUE)$ix
+      else
+        NULL
+    } else {
+      sort_connectivity <-
+        if (!is.null(connectivity))
+          sort(x = as.vector(unlist(connectivity)),
+               decreasing = TRUE,
+               index.return = TRUE)$x
+      else
+        NULL
+    }
+
+    if (variables) {
+      sort_silhouette <-
+        if (!is.null(silhouette))
+          sort(x = as.vector(unlist(silhouette)),
+               decreasing = TRUE,
+               index.return = TRUE)$ix
+      else
+        NULL
+    } else {
+      sort_silhouette <-
+        if (!is.null(silhouette))
+          sort(x = as.vector(unlist(silhouette)),
+               decreasing = TRUE,
+               index.return = TRUE)$x
+      else
+        NULL
+    }
+
+    if (is.null(sort_silhouette) && is.null(sort_dunn) && is.null(sort_connectivity)) sort_timeInternal <- NULL
+    if (is.null(distance)) distance <- '-'
+
+
+    resultadoValores$algorith = algorith
+    resultadoValores$distance = distance
+    resultadoValores$cluster = cluster
+    resultadoValores$dataset = dataset
+
+
+    if (!is.null(sort_timeInternal))
+      if (variables)  resultadoValores$timeInternal =
+      match(ranking, sort_timeInternal)
+    else resultadoValores$timeInternal =
+      format(round(as.numeric(sort_timeInternal[ranking]),
+                   digits = 4),scientific = FALSE)
+    if (!is.null(sort_connectivity))
+      if (variables)  resultadoValores$connectivity = sort_connectivity[ranking]
+    else resultadoValores$connectivity =
+      format(round(as.numeric(sort_connectivity[ranking]), digits = 4),
+             scientific = FALSE)
+    if (!is.null(sort_dunn))
+      if (variables)  resultadoValores$dunn = sort_dunn[ranking]
+    else resultadoValores$dunn = format(round(as.numeric(sort_dunn[ranking]),
+                                              digits = 4),scientific = FALSE)
+    if (!is.null(sort_silhouette))
+      if (variables)  resultadoValores$silhouette = sort_silhouette[ranking]
+    else resultadoValores$silhouette =
+      format(round(as.numeric(sort_silhouette[ranking]), digits = 4),
+             scientific = FALSE)
 
     return (resultadoValores)
 
