@@ -28,13 +28,13 @@ shinyUI(
                     "typeExecution",
                     label = h3(" Do you want to use test data or a file directory ? "),
                     choices = list("File Directory" = "directory", "Test Data" = "data"),
-                    inline = T,
+                    inline = TRUE,
                     selected = "data"
                 ),
                 shinyDirButton(id = "dir", label = "Directory Datasets", title = 'Select a directory'),
                 tags$br(),
                 tags$br(),
-                verbatimTextOutput("dir", placeholder = T),
+                verbatimTextOutput("dir", placeholder = TRUE),
                 selectInput(
                     inputId = "datasetTest",
                     label = h3("Dataset Test"),
@@ -45,14 +45,13 @@ shinyUI(
                         "Stulong" = "stulong",
                         "Weather" = "weather"
                     ),
-                    multiple = F,
+                    multiple = FALSE,
                     selected = "basketball"
                 ),
                 pickerInput(
                     inputId = "packages",
                     label = h3("Packages"),
                     choices = list(
-                        "Advclust" = "advclust",
                         "Amap" = "amap",
                         "Apcluster" = "apcluster",
                         "ClusterR" = "clusterr",
@@ -60,11 +59,11 @@ shinyUI(
                         "Pvclust" = "pvclust"
                     ),
                     options = list(
-                        `actions-box` = T,
+                        `actions-box` = TRUE,
                         size = 5,
                         `selected-text-format` = "count > 3"
                     ),
-                    multiple = T,
+                    multiple = TRUE,
                     selected = "cluster"
                 ),
                 pickerInput(
@@ -78,9 +77,6 @@ shinyUI(
                         "Diana" = "diana",
                         "Fanny" = "fanny",
                         "Gmm" = "gmm",
-                        "Fuzzy CM" = "fuzzy_cm",
-                        "Fuzzy GG" = "fuzzy_gg",
-                        "Fuzzy GK" = "fuzzy_gk",
                         "Hclust" = "hclust",
                         "Kmeans Arma" = "kmeans_arma",
                         "Kmeans Rcpp" = "kmeans_rcpp",
@@ -90,12 +86,12 @@ shinyUI(
                         "Pvclust" = "pvclust"
                     ),
                     options = list(
-                        `actions-box` = T,
+                        `actions-box` = TRUE,
                         size = 5,
                         `selected-text-format` = "count > 3"
                     ),
                     selected = c("kmeans_arma", "kmeans_rcpp", "mini_kmeans", "gmm"),
-                    multiple = T
+                    multiple = TRUE
                 ),
                 sliderInput(
                     "clustering",
@@ -108,32 +104,26 @@ shinyUI(
                     "metrics",
                     label = h3("Metrics"),
                     choices = list(
-                        "Connectivity" = "connectivity",
-                        "Dunn" = "dunn",
-                        "Entropy" = "entropy",
-                        "Fowlkes Mallows Index" = "fowlkes_mallows_index",
-                        "F-measure" = "f_measure",
-                        "Precision" = "precision",
-                        "Recall" = "recall",
-                        "Silhouette" = "silhouette",
-                        "Variation Information" = "variation_information"
+                        "Connectivity" = "Connectivity",
+                        "Dunn" = "Dunn",
+                        "Entropy" = "Entropy",
+                        "Fowlkes Mallows Index" = "Fowlkes_mallows_index",
+                        "F-measure" = "F_measure",
+                        "Precision" = "Precision",
+                        "Recall" = "Recall",
+                        "Silhouette" = "Silhouette",
+                        "Variation Information" = "Variation_information"
                     ),
                     options = list(
-                        `actions-box` = T,
+                        `actions-box` = TRUE,
                         size = 5,
                         `selected-text-format` = "count > 3"
                     ),
                     choicesOpt = list(
                         style = "height: 15px;"
                     ),
-                    multiple = T,
-                    selected = "precision"
-                ),
-                radioButtons(
-                    "visible",
-                    label = h3("Do you want to show the attributes of the dataset?"),
-                    choices = list("Yes" = T, "No" = F),
-                    inline = T
+                    multiple = TRUE,
+                    selected = "Precision"
                 )
 
             ),
@@ -154,7 +144,7 @@ shinyUI(
                             "image1",
                             h3("Metrics External", class="h3-clustering"),
                             choices = c(),
-                            multiple = F
+                            multiple = FALSE
                         )),
                         withSpinner(plotOutput("plotImage1"),color = "#4e5d6c"),
                         hidden(
@@ -162,7 +152,7 @@ shinyUI(
                                 "image2",
                                 h3("Metrics Internal",class="h3-clustering"),
                                 choices = c(),
-                                multiple = F
+                                multiple = FALSE
                             )),
                         plotOutput("plotImage2")
                     )
